@@ -22,11 +22,10 @@ class Aria2
     std::unique_ptr<Subprocess> mp_aria;
     int m_port;
     std::string m_secret;
-    std::string m_downloadDir;
     std::string doRequest(const MethodCall& methodCall);
 
   public:
-    Aria2();
+    explicit Aria2(std::string sessionFileDir);
     virtual ~Aria2() = default;
     void close();
 
