@@ -32,6 +32,7 @@
 
 #include <iostream>
 #include <iomanip>
+#include <regex>
 
 /* tell ICU where to find its dat file (tables) */
 void kiwix::loadICUExternalTables()
@@ -256,7 +257,7 @@ std::string kiwix::urlDecode(const std::string& value, bool component)
 
     // If there aren't enough characters left for this to be a
     // valid escape code, just use the character and move on
-    if (it > value.end() - 3) {
+    if (value.end() - it < 3) {
       os << *it;
       continue;
     }
@@ -439,3 +440,13 @@ template<>
 std::string kiwix::extractFromString(const std::string& str) {
   return str;
 }
+
+std::string kiwix::getSlugifiedFileName(const std::string& filename)
+{
+#ifdef _WIN32
+  const std::regex reservedCharsReg(R"([<>:"/\\|?*])");
+#else
+  const std::regex reservedCharsReg("/");
+#endif
+  return std::regex_replace(filename, reservedCharsReg, "_"); 
+}
