@@ -69,15 +69,66 @@ function $t(msgId, params={}) {
   }
 }
 
+const I18n = {
+  instantiateParameterizedMessages: function(data) {
+    if ( data.__proto__ == Array.prototype ) {
+      const result = [];
+      for ( const x of data ) {
+        result.push(this.instantiateParameterizedMessages(x));
+      }
+      return result;
+    } else if ( data.__proto__ == Object.prototype ) {
+      const msgId = data.msgid;
+      const msgParams = data.params;
+      if ( msgId && msgId.__proto__ == String.prototype && msgParams && msgParams.__proto__ == Object.prototype ) {
+        return $t(msgId, msgParams);
+      } else {
+        const result = {};
+        for ( const p in data ) {
+          result[p] = this.instantiateParameterizedMessages(data[p]);
+        }
+        return result;
+      }
+    } else {
+      return data;
+    }
+  },
+
+  render: function (template, params) {
+    params = this.instantiateParameterizedMessages(params);
+    return mustache.render(template, params);
+  }
+}
+
 const DEFAULT_UI_LANGUAGE = 'en';
 
 Translations.load(DEFAULT_UI_LANGUAGE, /*asDefault=*/true);
 
+// Below function selects the most suitable UI language from the list
+// of preferred languages in browser preferences and available translations.
+// Since, unlike Accept-Language header, navigator.languages doesn't contain
+// qvalues, they are computed using the same algorithm as in Firefox 121
+function getDefaultUserLanguage() {
+  const mostSuitableLang = { code: DEFAULT_UI_LANGUAGE, score: 0 }
+  const n = navigator.languages.length;
+  for (const lang of uiLanguages ) {
+    const rank = navigator.languages.indexOf(lang.iso_code);
+    if ( rank >= 0 ) {
+      const qvalue = Math.round(10*(1 - rank/n))/10;
+      const score = qvalue * lang.translation_count;
+      if ( score > mostSuitableLang.score ) {
+        mostSuitableLang.code = lang.iso_code;
+        mostSuitableLang.score = score;
+      }
+    }
+  }
+  return mostSuitableLang.code;
+}
+
 function getUserLanguage() {
   return new URLSearchParams(window.location.search).get('userlang')
       || window.localStorage.getItem('userlang')
-      || viewerSettings.defaultUserLanguage
-      || DEFAULT_UI_LANGUAGE;
+      || getDefaultUserLanguage();
 }
 
 function setUserLanguage(lang, callback) {
@@ -133,10 +184,8 @@ function initUILanguageSelector(activeLanguage, languageChangeCallback) {
   }
   const languageSelector = document.getElementById("ui_language");
   for (const lang of uiLanguages ) {
-    const lang_name = Object.getOwnPropertyNames(lang)[0];
-    const lang_code = lang[lang_name];
-    const is_selected = lang_code == activeLanguage;
-    languageSelector.appendChild(new Option(lang_name, lang_code, is_selected, is_selected));
+    const is_selected = lang.iso_code == activeLanguage;
+    languageSelector.appendChild(new Option(lang.self_name, lang.iso_code, is_selected, is_selected));
   }
   languageSelector.onchange = languageChangeCallback;
 }
@@ -145,3 +194,4 @@ window.$t = $t;
 window.getUserLanguage = getUserLanguage;
 window.setUserLanguage = setUserLanguage;
 window.initUILanguageSelector = initUILanguageSelector;
+window.I18n = I18n;
