@@ -78,15 +78,21 @@
         return result;
     }
 
+    function humanFriendlyNumStr(num, precision) {
+        const n = Math.abs(num).toFixed().length;
+        return num.toFixed(Math.max(0, precision - n));
+    }
+
     const humanFriendlySize = (fileSize) => {
         if (fileSize === 0) {
             return '';
         }
-        const units = ['bytes', 'kB', 'MB', 'GB', 'TB'];
-        let quotient = Math.floor(Math.log10(fileSize) / 3);
-        quotient = quotient < units.length ? quotient : units.length - 1;
-        fileSize /= (1000 ** quotient);
-        return `${+fileSize.toFixed(2)} ${units[quotient]}`;
+        const units = ['bytes', 'KiB', 'MiB', 'GiB', 'TiB'];
+        let quotient = Math.floor(Math.log2(fileSize) / 10);
+        quotient = Math.min(quotient, units.length - 1);
+        fileSize /= (1024 ** quotient);
+        const fileSizeStr = humanFriendlyNumStr(fileSize, 3);
+        return `${fileSizeStr} ${units[quotient]}`;
     };
 
     const humanFriendlyTitle = (title) => {
@@ -99,6 +105,14 @@
         return '';
     }
 
+    // Borrowed from https://stackoverflow.com/a/1912522
+    function htmlDecode(input){
+      var e = document.createElement('textarea');
+      e.innerHTML = input;
+      // handle case of empty input
+      return e.childNodes.length === 0 ? "" : e.childNodes[0].nodeValue;
+    }
+
     function htmlEncode(str) {
         return str.replace(/[\u00A0-\u9999<>\&]/gim, (i) => `&#${i.charCodeAt(0)};`);
     }
@@ -115,9 +129,27 @@
 
     function generateTagLink(tagValue) {
         tagValue = tagValue.toLowerCase();
-        const humanFriendlyTagValue = humanFriendlyTitle(tagValue);
-        const tagMessage = $t("filter-by-tag", {TAG: humanFriendlyTagValue});
-        return `<span class='tag__link' aria-label='${tagMessage}' title='${tagMessage}' data-tag=${tagValue}>${humanFriendlyTagValue}</span>`
+        const tagMessage = $t("filter-by-tag", {TAG: tagValue});
+        const spanElement = document.createElement("span");
+        spanElement.className = 'tag__link';
+        spanElement.setAttribute('aria-label', tagMessage);
+        spanElement.setAttribute('title', tagMessage);
+        spanElement.setAttribute('data-tag', tagValue);
+        spanElement.innerHTML = htmlEncode(tagValue);
+        return spanElement.outerHTML;
+    }
+
+    function downloadButtonText(zimSize) {
+      return $t("download") + (zimSize ? ` - ${zimSize}`: '');
+    }
+
+    function downloadButtonHtml(url, zimSize) {
+        return url
+             ? `<div class="book__download" data-link="${url}" data-size="${zimSize}">
+                  <img src="${root}/skin/download-white.svg?KIWIXCACHEID">
+                  <span ">${downloadButtonText(zimSize)}</span>
+                </div>`
+             : '';
     }
 
     function generateBookHtml(book, sort = false) {
@@ -138,7 +170,7 @@
             const mulLangList = langCodesList.filter(x => languages.hasOwnProperty(x)).map(x => languages[x]);
             language = mulLangList.join(', ');
         }
-        const tags = getInnerHtml(book, 'tags');
+        const tags = htmlDecode(getInnerHtml(book, 'tags'));
         const tagList = tags.split(';').filter(tag => {return !(tag.startsWith('_'))});
         const tagFilterLinks = tagList.map((tagValue) => generateTagLink(tagValue));
         const tagHtml = tagFilterLinks.join(' | ');
@@ -164,6 +196,7 @@
         }
         const faviconAttr = iconUrl != undefined ? `style="background-image: url('${iconUrl}')"` : '';
         const languageAttr = langCode != '' ? `title="${language}" aria-label="${language}"` : 'style="background-color: transparent"';
+
         divTag.innerHTML = `
             <div class="book__wrapper">
             <a class="book__link" href="${viewerLink}" data-hover="Preview">
@@ -171,13 +204,15 @@
             <div class="book__icon" ${faviconAttr}></div>
             <div class="book__header">
                 <div id="book__title">${title}</div>
-                ${downloadLink ? `<div class="book__download"><span data-link="${downloadLink}">${$t("download")} ${humanFriendlyZimSize ? ` - ${humanFriendlyZimSize}</span></div>`: ''}` : ''}
             </div>
             <div class="book__description" title="${description}">${description}</div>
             </div>
             </a>
+            <div class="book__meta">
             <div class="book__languageTag" ${languageAttr}>${getLanguageCodeToDisplay(langCode)}</div>
             <div class="book__tags"><div class="book__tags--wrapper">${tagHtml}</div></div>
+            </div>
+            ${downloadButtonHtml(downloadLink, humanFriendlyZimSize)}
             </div></div>`;
         return divTag;
     }
@@ -263,6 +298,7 @@
     }
 
     function insertModal(button) {
+        const downloadSize = button.getAttribute('data-size');
         const downloadLink = button.getAttribute('data-link');
         button.addEventListener('click', async (event) => {
             event.preventDefault();
@@ -272,7 +308,7 @@
                     <div class="modal-heading">
                         <div class="modal-title">
                             <div>
-                                Download
+                                ${downloadButtonText(downloadSize)}
                             </div>
                         </div>
                         <div onclick="closeModal()" class="modal-close-button">
@@ -432,7 +468,7 @@
         booksToDelete.forEach(book => {iso.remove(book);});
         books.forEach((book) => {
             iso.insert(generateBookHtml(book, sort))
-            const downloadButton = document.querySelector(`[data-id="${getInnerHtml(book, 'id')}"] .book__download span`);
+            const downloadButton = document.querySelector(`[data-id="${getInnerHtml(book, 'id')}"] .book__download`);
             if (downloadButton) {
                 insertModal(downloadButton);
             }
@@ -486,9 +522,8 @@
     function addTagElement(tagValue, resetFilter) {
         const tagElement = document.getElementsByClassName('tagFilterLabel')[0];
         tagElement.style.display = 'inline-block';
-        const humanFriendlyTagValue = humanFriendlyTitle(tagValue);
-        tagElement.innerHTML = `${humanFriendlyTagValue}`;
-        const tagMessage = $t("stop-filtering-by-tag", {TAG: humanFriendlyTagValue});
+        tagElement.innerHTML = htmlEncode(tagValue);
+        const tagMessage = $t("stop-filtering-by-tag", {TAG: tagValue});
         tagElement.setAttribute('aria-label', tagMessage);
         tagElement.setAttribute('title', tagMessage);
         if (resetFilter)
