@@ -1,6 +1,5 @@
 const viewerSettings = {
   toolbarEnabled:       {{enable_toolbar}},
   linkBlockingEnabled:  {{enable_link_blocking}},
-  libraryButtonEnabled: {{enable_library_button}},
-  defaultUserLanguage:  "{{default_user_language}}"
+  libraryButtonEnabled: {{enable_library_button}}
 }
