@@ -103,7 +103,7 @@ std::string maskVariableOPDSFeedData(std::string s)
 #define _CHARLES_RAY_CATALOG_ENTRY(CONTENT_NAME) CATALOG_ENTRY(  \
   "charlesray",   \
   "Charles, Ray", \
-  "Wikipedia articles about Ray Charles", \
+  "Wikipedia articles about Ray Charles or why and when one should go to library", \
   "fra", \
   "wikipedia_fr_ray_charles",\
   "jazz",\
@@ -120,7 +120,7 @@ std::string maskVariableOPDSFeedData(std::string s)
 #define _RAY_CHARLES_CATALOG_ENTRY(CONTENT_NAME) CATALOG_ENTRY(\
   "raycharles",\
   "Ray Charles",\
-  "Wikipedia articles about Ray Charles",\
+  "Wikipedia articles about Ray Charles (not all of them but near to what an average newborn may find more than enough)",\
   "eng",\
   "wikipedia_en_ray_charles",\
   "wikipedia",\
@@ -129,24 +129,24 @@ std::string maskVariableOPDSFeedData(std::string s)
   "          href=\"/ROOT%23%3F/catalog/v2/illustration/raycharles/?size=48\"\n" \
   "          type=\"image/png;width=48;height=48;scale=1\"/>\n    ", \
   CONTENT_NAME, \
-  "zimfile", \
+  "zimfile_raycharles", \
   "569344"\
 )
 
-#define RAY_CHARLES_CATALOG_ENTRY           _RAY_CHARLES_CATALOG_ENTRY("zimfile")
+#define RAY_CHARLES_CATALOG_ENTRY           _RAY_CHARLES_CATALOG_ENTRY("zimfile_raycharles")
 #define RAY_CHARLES_CATALOG_ENTRY_NO_MAPPER _RAY_CHARLES_CATALOG_ENTRY("raycharles")
 
 #define UNCATEGORIZED_RAY_CHARLES_CATALOG_ENTRY CATALOG_ENTRY(\
   "raycharles_uncategorized",\
   "Ray (uncategorized) Charles",\
-  "No category is assigned to this library entry.",\
+  "No category is assigned to this library entry (neither adj nor xor was considered a good option)",\
   "rus,eng",\
   "wikipedia_ru_ray_charles",\
   "",\
   "public_tag_with_a_value:value_of_a_public_tag;_private_tag_with_a_value:value_of_a_private_tag;wikipedia;_pictures:no;_videos:no;_details:no",\
   "",\
-  "zimfile", \
-  "zimfile", \
+  "zimfile_raycharles_uncategorized", \
+  "zimfile_raycharles_uncategorized", \
   "125952"\
 )
 
@@ -199,8 +199,8 @@ TEST_F(LibraryServerTest, catalog_search_by_phrase)
     "  <startIndex>0</startIndex>\n"
     "  <itemsPerPage>2</itemsPerPage>\n"
     CATALOG_LINK_TAGS
-    RAY_CHARLES_CATALOG_ENTRY
     CHARLES_RAY_CATALOG_ENTRY
+    RAY_CHARLES_CATALOG_ENTRY
     "</feed>\n"
   );
 }
@@ -218,8 +218,8 @@ TEST_F(LibraryServerTest, catalog_search_by_words)
     "  <startIndex>0</startIndex>\n"
     "  <itemsPerPage>3</itemsPerPage>\n"
     CATALOG_LINK_TAGS
-    RAY_CHARLES_CATALOG_ENTRY
     CHARLES_RAY_CATALOG_ENTRY
+    RAY_CHARLES_CATALOG_ENTRY
     UNCATEGORIZED_RAY_CHARLES_CATALOG_ENTRY
     "</feed>\n"
   );
@@ -239,8 +239,8 @@ TEST_F(LibraryServerTest, catalog_prefix_search)
       "  <startIndex>0</startIndex>\n"
       "  <itemsPerPage>2</itemsPerPage>\n"
       CATALOG_LINK_TAGS
-      RAY_CHARLES_CATALOG_ENTRY
       CHARLES_RAY_CATALOG_ENTRY
+      RAY_CHARLES_CATALOG_ENTRY
       "</feed>\n"
     );
   }
@@ -275,8 +275,8 @@ TEST_F(LibraryServerTest, catalog_search_with_word_exclusion)
     "  <startIndex>0</startIndex>\n"
     "  <itemsPerPage>2</itemsPerPage>\n"
     CATALOG_LINK_TAGS
-    RAY_CHARLES_CATALOG_ENTRY
     CHARLES_RAY_CATALOG_ENTRY
+    RAY_CHARLES_CATALOG_ENTRY
     "</feed>\n"
   );
 }
@@ -331,8 +331,8 @@ TEST_F(LibraryServerTest, catalog_search_by_category)
       "  <startIndex>0</startIndex>\n"
       "  <itemsPerPage>2</itemsPerPage>\n"
       CATALOG_LINK_TAGS
-      RAY_CHARLES_CATALOG_ENTRY
       CHARLES_RAY_CATALOG_ENTRY
+      RAY_CHARLES_CATALOG_ENTRY
       "</feed>\n"
     );
   }
@@ -772,10 +772,171 @@ TEST_F(LibraryServerTest, catalog_v2_entries_filtered_by_search_terms)
     "  <totalResults>2</totalResults>\n"
     "  <startIndex>0</startIndex>\n"
     "  <itemsPerPage>2</itemsPerPage>\n"
+    CHARLES_RAY_CATALOG_ENTRY
     RAY_CHARLES_CATALOG_ENTRY
+    "</feed>\n"
+  );
+}
+
+TEST_F(LibraryServerTest, catalog_v2_entries_filtering_special_queries)
+{
+  {
+  // 'or' doesn't act as a Xapian boolean operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=Or");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=Or")
+    "  <title>Filtered Entries (q=Or)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
     CHARLES_RAY_CATALOG_ENTRY
     "</feed>\n"
   );
+  }
+
+  {
+  // 'and' doesn't act as a Xapian boolean operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=and");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=and")
+    "  <title>Filtered Entries (q=and)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
+    CHARLES_RAY_CATALOG_ENTRY
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'not' doesn't act as a Xapian boolean operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=not");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=not")
+    "  <title>Filtered Entries (q=not)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
+    RAY_CHARLES_CATALOG_ENTRY
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'xor' doesn't act as a Xapian boolean operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=xor");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=xor")
+    "  <title>Filtered Entries (q=xor)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
+    UNCATEGORIZED_RAY_CHARLES_CATALOG_ENTRY
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'or' acts as a Xapian boolean operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=wikipedia%20or%20library");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=wikipedia%20or%20library")
+    "  <title>Filtered Entries (q=wikipedia%20or%20library)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
+    CHARLES_RAY_CATALOG_ENTRY
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'and' acts as a Xapian boolean operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=wikipedia%20and%20articles");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=wikipedia%20and%20articles")
+    "  <title>Filtered Entries (q=wikipedia%20and%20articles)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
+    CHARLES_RAY_CATALOG_ENTRY
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'near' doesn't act as a Xapian query operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=near");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=near")
+    "  <title>Filtered Entries (q=near)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
+    RAY_CHARLES_CATALOG_ENTRY
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'adj' doesn't act as a Xapian query operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=adj");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=adj")
+    "  <title>Filtered Entries (q=adj)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>1</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>1</itemsPerPage>\n"
+    UNCATEGORIZED_RAY_CHARLES_CATALOG_ENTRY
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'near' doesn't act as a Xapian query operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=charles%20near%20why");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=charles%20near%20why")
+    "  <title>Filtered Entries (q=charles%20near%20why)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>0</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>0</itemsPerPage>\n"
+    "</feed>\n"
+  );
+  }
+
+  {
+  // 'adj' doesn't act as a Xapian query operator
+  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?q=charles%20adj%20why");
+  EXPECT_EQ(r->status, 200);
+  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+    CATALOG_V2_ENTRIES_PREAMBLE("?q=charles%20adj%20why")
+    "  <title>Filtered Entries (q=charles%20adj%20why)</title>\n"
+    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+    "  <totalResults>0</totalResults>\n"
+    "  <startIndex>0</startIndex>\n"
+    "  <itemsPerPage>0</itemsPerPage>\n"
+    "</feed>\n"
+  );
+  }
 }
 
 TEST_F(LibraryServerTest, catalog_v2_entries_filtered_by_language)
@@ -841,8 +1002,8 @@ TEST_F(LibraryServerTest, catalog_v2_entries_filtered_by_category)
       "  <totalResults>2</totalResults>\n"
       "  <startIndex>0</startIndex>\n"
       "  <itemsPerPage>2</itemsPerPage>\n"
-      RAY_CHARLES_CATALOG_ENTRY
       CHARLES_RAY_CATALOG_ENTRY
+      RAY_CHARLES_CATALOG_ENTRY
       "</feed>\n"
     );
   }
@@ -1033,7 +1194,7 @@ TEST_F(LibraryServerTest, no_name_mapper_catalog_v2_individual_entry_access)
   "    />\n" \
   "    <link\n" \
   "      type=\"text/css\"\n" \
-  "      href=\"/ROOT%23%3F/skin/index.css?cacheid=1e78e7cf\"\n" \
+  "      href=\"/ROOT%23%3F/skin/index.css?cacheid=ae79e41a\"\n" \
   "      rel=\"Stylesheet\"\n" \
   "    />\n" \
   "    <link rel=\"apple-touch-icon\" sizes=\"180x180\" href=\"/ROOT%23%3F/skin/favicon/apple-touch-icon.png?cacheid=f86f8df3\">\n" \
@@ -1066,17 +1227,10 @@ TEST_F(LibraryServerTest, no_name_mapper_catalog_v2_individual_entry_access)
   "      .tag__link {\n" \
   "        pointer-events: none;\n" \
   "      }\n\n" \
-  "      .book__link__wrapper {\n" \
-  "        grid-column: 1 / 3;\n" \
-  "        grid-row: 1 / 3;\n" \
-  "      }\n\n" \
-  "      .book__link {\n" \
-  "        grid-row: 2 / 3;\n" \
-  "      }\n\n" \
   "      .kiwixHomeBody__results {\n" \
   "        flex-basis: 100%;\n" \
   "      }\n\n" \
-  "      #book__title>a, .book__download a {\n" \
+  "      #book__title>a {\n" \
   "        text-decoration: none;\n" \
   "        all: unset;\n" \
   "      }\n" \
@@ -1087,62 +1241,83 @@ TEST_F(LibraryServerTest, no_name_mapper_catalog_v2_individual_entry_access)
 
 #define CHARLES_RAY_BOOK_HTML \
   "        <div class=\"book__wrapper\">\n" \
-  "                <div class=\"book__link__wrapper\">\n" \
-  "                    <div class=\"book__icon\" style=background-image:url(/ROOT%23%3F/catalog/v2/illustration/charlesray/?size=48)></div>\n" \
-  "                    <div class=\"book__header\">\n" \
-  "                        <div id=\"book__title\"><a href=\"/ROOT%23%3F/content/zimfile%26other\">Charles, Ray</a></div>\n" \
-  "                        <div class=\"book__download\"><span><a href=\"/ROOT%23%3F/nojs/download/zimfile%26other\">Download</a></span></div>\n" \
-  "                    </div>\n" \
-  "                    <a class=\"book__link\" href=\"/ROOT%23%3F/content/zimfile%26other\" title=\"Preview\" aria-label=\"Preview\">\n" \
-  "                      <div class=\"book__description\" title=\"Wikipedia articles about Ray Charles\">Wikipedia articles about Ray Charles</div>\n" \
-  "                    </a>\n" \
+  "            <a class=\"book__link\" href=\"/ROOT%23%3F/content/zimfile%26other\" title=\"Preview\" aria-label=\"Preview\">\n" \
+  "            <div class=\"book__link__wrapper\">\n" \
+  "            <div class=\"book__icon\" style=background-image:url(/ROOT%23%3F/catalog/v2/illustration/charlesray/?size=48)></div>\n" \
+  "            <div class=\"book__header\">\n" \
+  "                <div id=\"book__title\">Charles, Ray</div>\n" \
+  "            </div>\n" \
+  "            <div class=\"book__description\" title=\"Wikipedia articles about Ray Charles or why and when one should go to library\">Wikipedia articles about Ray Charles or why and when one should go to library</div>\n" \
+  "            </div>\n" \
+  "            </a>\n" \
+  "            <div class=\"book__meta\">\n" \
+  "              <div class=\"book__languageTag\" >fra</div>\n" \
+  "              <div class=\"book__tags\"><div class=\"book__tags--wrapper\">\n" \
+  "                  <span class=\"tag__link\" aria-label='unittest' title='unittest'>unittest</span>\n" \
+  "                  <span class=\"tag__link\" aria-label='wikipedia' title='wikipedia'>wikipedia</span>\n" \
   "              </div>\n" \
-  "            <div class=\"book__languageTag\" >fra</div>\n" \
-  "            <div class=\"book__tags\"><div class=\"book__tags--wrapper\">\n" \
-  "                <span class=\"tag__link\" aria-label='unittest' title='unittest'>unittest</span>\n" \
-  "                <span class=\"tag__link\" aria-label='wikipedia' title='wikipedia'>wikipedia</span>\n" \
+  "              </div>\n" \
+  "            </div>\n" \
+  "            <div>\n" \
+  "              <a class=\"book__download\" href=\"/ROOT%23%3F/nojs/download/zimfile%26other\">\n" \
+  "                <img src=\"/ROOT%23%3F/skin/download-white.svg?cacheid=079ab989\">\n" \
+  "                <span>Download</span>\n" \
+  "              </a>\n" \
   "            </div>\n" \
-  "        </div>\n" \
   "        </div>\n"
 
 #define RAY_CHARLES_BOOK_HTML \
   "        <div class=\"book__wrapper\">\n" \
-  "                <div class=\"book__link__wrapper\">\n" \
-  "                    <div class=\"book__icon\" style=background-image:url(/ROOT%23%3F/catalog/v2/illustration/raycharles/?size=48)></div>\n" \
-  "                    <div class=\"book__header\">\n" \
-  "                        <div id=\"book__title\"><a href=\"/ROOT%23%3F/content/zimfile\">Ray Charles</a></div>\n" \
-  "                        <div class=\"book__download\"><span><a href=\"/ROOT%23%3F/nojs/download/zimfile\">Download</a></span></div>\n" \
-  "                    </div>\n" \
-  "                    <a class=\"book__link\" href=\"/ROOT%23%3F/content/zimfile\" title=\"Preview\" aria-label=\"Preview\">\n" \
-  "                      <div class=\"book__description\" title=\"Wikipedia articles about Ray Charles\">Wikipedia articles about Ray Charles</div>\n" \
-  "                    </a>\n" \
+  "            <a class=\"book__link\" href=\"/ROOT%23%3F/content/zimfile_raycharles\" title=\"Preview\" aria-label=\"Preview\">\n" \
+  "            <div class=\"book__link__wrapper\">\n" \
+  "            <div class=\"book__icon\" style=background-image:url(/ROOT%23%3F/catalog/v2/illustration/raycharles/?size=48)></div>\n" \
+  "            <div class=\"book__header\">\n" \
+  "                <div id=\"book__title\">Ray Charles</div>\n" \
+  "            </div>\n" \
+  "            <div class=\"book__description\" title=\"Wikipedia articles about Ray Charles (not all of them but near to what an average newborn may find more than enough)\">Wikipedia articles about Ray Charles (not all of them but near to what an average newborn may find more than enough)</div>\n" \
+  "            </div>\n" \
+  "            </a>\n" \
+  "            <div class=\"book__meta\">\n" \
+  "              <div class=\"book__languageTag\" >eng</div>\n" \
+  "              <div class=\"book__tags\"><div class=\"book__tags--wrapper\">\n" \
+  "                  <span class=\"tag__link\" aria-label='public_tag_without_a_value' title='public_tag_without_a_value'>public_tag_without_a_value</span>\n" \
+  "                  <span class=\"tag__link\" aria-label='wikipedia' title='wikipedia'>wikipedia</span>\n" \
   "              </div>\n" \
-  "            <div class=\"book__languageTag\" >eng</div>\n" \
-  "            <div class=\"book__tags\"><div class=\"book__tags--wrapper\">\n" \
-  "                <span class=\"tag__link\" aria-label='public_tag_without_a_value' title='public_tag_without_a_value'>public_tag_without_a_value</span>\n" \
-  "                <span class=\"tag__link\" aria-label='wikipedia' title='wikipedia'>wikipedia</span>\n" \
+  "              </div>\n" \
+  "            </div>\n" \
+  "            <div>\n" \
+  "              <a class=\"book__download\" href=\"/ROOT%23%3F/nojs/download/zimfile_raycharles\">\n" \
+  "                <img src=\"/ROOT%23%3F/skin/download-white.svg?cacheid=079ab989\">\n" \
+  "                <span>Download</span>\n" \
+  "              </a>\n" \
   "            </div>\n" \
-  "        </div>\n" \
   "        </div>\n"
 
 #define RAY_CHARLES_UNCTZ_BOOK_HTML \
   "        <div class=\"book__wrapper\">\n" \
-  "                <div class=\"book__link__wrapper\">\n" \
-  "                    <div class=\"book__icon\" style=background-image:url(/ROOT%23%3F/catalog/v2/illustration/raycharles_uncategorized/?size=48)></div>\n" \
-  "                    <div class=\"book__header\">\n" \
-  "                        <div id=\"book__title\"><a href=\"/ROOT%23%3F/content/zimfile\">Ray (uncategorized) Charles</a></div>\n" \
-  "                        <div class=\"book__download\"><span><a href=\"/ROOT%23%3F/nojs/download/zimfile\">Download</a></span></div>\n" \
-  "                    </div>\n" \
-  "                    <a class=\"book__link\" href=\"/ROOT%23%3F/content/zimfile\" title=\"Preview\" aria-label=\"Preview\">\n" \
-  "                      <div class=\"book__description\" title=\"No category is assigned to this library entry.\">No category is assigned to this library entry.</div>\n" \
-  "                    </a>\n" \
+  "            <a class=\"book__link\" href=\"/ROOT%23%3F/content/zimfile_raycharles_uncategorized\" title=\"Preview\" aria-label=\"Preview\">\n" \
+  "            <div class=\"book__link__wrapper\">\n" \
+  "            <div class=\"book__icon\" style=background-image:url(/ROOT%23%3F/catalog/v2/illustration/raycharles_uncategorized/?size=48)></div>\n" \
+  "            <div class=\"book__header\">\n" \
+  "                <div id=\"book__title\">Ray (uncategorized) Charles</div>\n" \
+  "            </div>\n" \
+  "            <div class=\"book__description\" title=\"No category is assigned to this library entry (neither adj nor xor was considered a good option)\">No category is assigned to this library entry (neither adj nor xor was considered a good option)</div>\n" \
+  "            </div>\n" \
+  "            </a>\n" \
+  "            <div class=\"book__meta\">\n" \
+  "              <div class=\"book__languageTag\" >rus,eng</div>\n" \
+  "              <div class=\"book__tags\"><div class=\"book__tags--wrapper\">\n" \
+  "                  <span class=\"tag__link\" aria-label='public_tag_with_a_value:value_of_a_public_tag' title='public_tag_with_a_value:value_of_a_public_tag'>public_tag_with_a_value:value_of_a_public_tag</span>\n" \
+  "                  <span class=\"tag__link\" aria-label='wikipedia' title='wikipedia'>wikipedia</span>\n" \
   "              </div>\n" \
-  "            <div class=\"book__languageTag\" >rus,eng</div>\n" \
-  "            <div class=\"book__tags\"><div class=\"book__tags--wrapper\">\n" \
-  "                <span class=\"tag__link\" aria-label='public_tag_with_a_value:value_of_a_public_tag' title='public_tag_with_a_value:value_of_a_public_tag'>public_tag_with_a_value:value_of_a_public_tag</span>\n" \
-  "                <span class=\"tag__link\" aria-label='wikipedia' title='wikipedia'>wikipedia</span>\n" \
+  "              </div>\n" \
+  "            </div>\n" \
+  "            <div>\n" \
+  "              <a class=\"book__download\" href=\"/ROOT%23%3F/nojs/download/zimfile_raycharles_uncategorized\">\n" \
+  "                <img src=\"/ROOT%23%3F/skin/download-white.svg?cacheid=079ab989\">\n" \
+  "                <span>Download</span>\n" \
+  "              </a>\n" \
   "            </div>\n" \
-  "        </div>\n" \
   "        </div>\n"
 
 #define FINAL_HTML_TEXT \
@@ -1171,7 +1346,7 @@ TEST_F(LibraryServerTest, no_name_mapper_catalog_v2_individual_entry_access)
   "        </div>\n" \
   "      </div>\n" \
   "      <form id='kiwixSearchForm' class='kiwixNav__SearchForm' action=\"/ROOT%23%3F/nojs\">\n" \
-  "        <input type=\"text\" name=\"q\" placeholder=\"Search\" id=\"searchFilter\" class='kiwixSearch filter' value=\"\">\n" \
+  "        <input type=\"text\" name=\"q\" accesskey=\"s\" placeholder=\"Search\" id=\"searchFilter\" class='kiwixSearch filter' value=\"\">\n" \
   "        <input type=\"submit\" class=\"kiwixButton kiwixButtonHover\" value=\"Search\"/>\n" \
   "      </form>\n" \
   "    </div>\n"
@@ -1224,17 +1399,17 @@ TEST_F(LibraryServerTest, no_name_mapper_catalog_v2_individual_entry_access)
   "    <div class=\"downloadLinksTitle\">\n" \
   "        Download links for <b><i>Ray (uncategorized) Charles</i></b>\n" \
   "    </div>\n" \
-  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile.zim\" download>\n" \
+  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile_raycharles_uncategorized.zim\" download>\n" \
   "        <div>Direct</div>\n" \
   "    </a>\n" \
-  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile.zim.sha256\" download>\n" \
-  "        <div>Sha256 hash</div>\n" \
+  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile_raycharles_uncategorized.zim.sha256\" download>\n" \
+  "        <div>SHA-256 checksum</div>\n" \
   "    </a>\n" \
-  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile.zim.magnet\" target=\"_blank\">\n" \
+  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile_raycharles_uncategorized.zim.magnet\" target=\"_blank\">\n" \
   "        <div>Magnet link</div>\n" \
   "    </a>\n" \
-  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile.zim.torrent\" download>\n" \
-  "        <div>Torrent file</div>\n" \
+  "    <a href=\"https://github.com/kiwix/libkiwix/raw/master/test/data/zimfile_raycharles_uncategorized.zim.torrent\" download>\n" \
+  "        <div>BitTorrent</div>\n" \
   "    </a>\n" \
   "</body>\n" \
   "</html>"
@@ -1273,7 +1448,7 @@ TEST_F(LibraryServerTest, noJS) {
             FINAL_HTML_TEXT);
 
   // no_js_download
-  r = zfs1_->GET("/ROOT%23%3F/nojs/download/zimfile");
+  r = zfs1_->GET("/ROOT%23%3F/nojs/download/zimfile_raycharles_uncategorized");
   EXPECT_EQ(r->status, 200);
   EXPECT_EQ(r->body, RAY_CHARLES_UNCTZ_DOWNLOAD);
 }
