@@ -18,9 +18,10 @@
  */
 
 #include "gtest/gtest.h"
+#include "../include/tools.h"
 #include "../src/tools/otherTools.h"
 #include "zim/suggestion_iterator.h"
-#include "../src/server/i18n.h"
+#include "../src/server/i18n_utils.h"
 
 #include <regex>
 
@@ -233,3 +234,27 @@ TEST(I18n, parseUserLanguagePreferences)
       "{fr, 1}{en, 0.5}"
   );
 }
+
+#include "../include/tools.h"
+
+TEST(networkTools, getNetworkInterfacesIPv4Or6)
+{
+  for ( const auto& kv : kiwix::getNetworkInterfacesIPv4Or6() ) {
+    std::cout << kv.first << " : IPv4 addr = " << kv.second.addr
+                          << " ; IPv6 addr = " << kv.second.addr6
+                          << std::endl;
+  }
+}
+
+TEST(networkTools, getNetworkInterfaces)
+{
+  for ( const auto& kv : kiwix::getNetworkInterfaces() ) {
+    std::cout << kv.first << " : IPv4 addr = " << kv.second << std::endl;
+  }
+}
+
+TEST(networkTools, getBestPublicIps)
+{
+  std::cout << "getBestPublicIps(): " << "[" << kiwix::getBestPublicIps().addr << ", " << kiwix::getBestPublicIps().addr6 << "]" << std::endl;
+  std::cout << "getBestPublicIp(): " << kiwix::getBestPublicIp() << std::endl;
+}
