@@ -61,9 +61,9 @@ const ResourceCollection resources200Compressible{
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/i18n.js" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/i18n.js?cacheid=071abc9a" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/index.css" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.css?cacheid=1e78e7cf" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.css?cacheid=ae79e41a" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/index.js" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.js?cacheid=ce19da2a" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.js?cacheid=8f4b6a1e" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/iso6391To3.js" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/iso6391To3.js?cacheid=ecde2bb3" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/isotope.pkgd.min.js" },
@@ -73,9 +73,9 @@ const ResourceCollection resources200Compressible{
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/mustache.min.js" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/mustache.min.js?cacheid=bd23c4fb" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/taskbar.css" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/taskbar.css?cacheid=e014a885" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/taskbar.css?cacheid=80d56607" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/viewer.js" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/viewer.js?cacheid=5fc4badf" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/viewer.js?cacheid=aca897b0" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/fonts/Poppins.ttf" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/fonts/Poppins.ttf?cacheid=af705837" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/fonts/Roboto.ttf" },
@@ -84,7 +84,7 @@ const ResourceCollection resources200Compressible{
   // TODO: implement cache management of i18n resources
   //{ STATIC_CONTENT, "/ROOT%23%3F/skin/i18n/test.json?cacheid=unknown" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/languages.js" },
-  { STATIC_CONTENT, "/ROOT%23%3F/skin/languages.js?cacheid=5be77f5c" },
+  { STATIC_CONTENT, "/ROOT%23%3F/skin/languages.js?cacheid=ee7d95b5" },
 
   { DYNAMIC_CONTENT, "/ROOT%23%3F/catalog/search" },
 
@@ -114,6 +114,8 @@ const ResourceCollection resources200Uncompressible{
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/caret.png?cacheid=22b942b4" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/download.png" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/download.png?cacheid=a39aa502" },
+  { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/download-white.svg" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/download-white.svg?cacheid=079ab989"},
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/favicon/android-chrome-192x192.png" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/favicon/android-chrome-192x192.png?cacheid=bfac158b" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/favicon/android-chrome-512x512.png" },
@@ -279,7 +281,7 @@ TEST_F(ServerTest, CacheIdsOfStaticResources)
     {
       /* url */ "/ROOT%23%3F/",
 R"EXPECTEDRESULT(      href="/ROOT%23%3F/skin/kiwix.css?cacheid=2158fad9"
-      href="/ROOT%23%3F/skin/index.css?cacheid=1e78e7cf"
+      href="/ROOT%23%3F/skin/index.css?cacheid=ae79e41a"
     <link rel="apple-touch-icon" sizes="180x180" href="/ROOT%23%3F/skin/favicon/apple-touch-icon.png?cacheid=f86f8df3">
     <link rel="icon" type="image/png" sizes="32x32" href="/ROOT%23%3F/skin/favicon/favicon-32x32.png?cacheid=79ded625">
     <link rel="icon" type="image/png" sizes="16x16" href="/ROOT%23%3F/skin/favicon/favicon-16x16.png?cacheid=a986fedc">
@@ -289,10 +291,10 @@ R"EXPECTEDRESULT(      href="/ROOT%23%3F/skin/kiwix.css?cacheid=2158fad9"
     <meta name="msapplication-config" content="/ROOT%23%3F/skin/favicon/browserconfig.xml?cacheid=f29a7c4a">
     <script type="text/javascript" src="./skin/polyfills.js?cacheid=a0e0343d"></script>
     <script type="module" src="/ROOT%23%3F/skin/i18n.js?cacheid=071abc9a" defer></script>
-    <script type="text/javascript" src="/ROOT%23%3F/skin/languages.js?cacheid=5be77f5c" defer></script>
+    <script type="text/javascript" src="/ROOT%23%3F/skin/languages.js?cacheid=ee7d95b5" defer></script>
     <script src="/ROOT%23%3F/skin/isotope.pkgd.min.js?cacheid=2e48d392" defer></script>
     <script src="/ROOT%23%3F/skin/iso6391To3.js?cacheid=ecde2bb3"></script>
-    <script type="text/javascript" src="/ROOT%23%3F/skin/index.js?cacheid=ce19da2a" defer></script>
+    <script type="text/javascript" src="/ROOT%23%3F/skin/index.js?cacheid=8f4b6a1e" defer></script>
         <img src="/ROOT%23%3F/skin/feed.svg?cacheid=055b333f"
         <img src="/ROOT%23%3F/skin/langSelector.svg?cacheid=00b59961"
 )EXPECTEDRESULT"
@@ -310,7 +312,8 @@ R"EXPECTEDRESULT(    background-image: url('../skin/search-icon.svg?cacheid=b10a
     },
     {
       /* url */ "/ROOT%23%3F/skin/index.js",
-R"EXPECTEDRESULT(                                <img src="${root}/skin/download.png?cacheid=a39aa502" alt="${$t("direct-download-alt-text")}" />
+R"EXPECTEDRESULT(                  <img src="${root}/skin/download-white.svg?cacheid=079ab989">
+                                <img src="${root}/skin/download.png?cacheid=a39aa502" alt="${$t("direct-download-alt-text")}" />
                                 <img src="${root}/skin/hash.png?cacheid=f836e872" alt="${$t("hash-download-alt-text")}" />
                                 <img src="${root}/skin/magnet.png?cacheid=73b6bddf" alt="${$t("magnet-alt-text")}" />
                                 <img src="${root}/skin/bittorrent.png?cacheid=4f5c6882" alt="${$t("torrent-download-alt-text")}" />
@@ -319,12 +322,12 @@ R"EXPECTEDRESULT(                                <img src="${root}/skin/download
     {
       /* url */ "/ROOT%23%3F/viewer",
 R"EXPECTEDRESULT(    <link type="text/css" href="./skin/kiwix.css?cacheid=2158fad9" rel="Stylesheet" />
-    <link type="text/css" href="./skin/taskbar.css?cacheid=e014a885" rel="Stylesheet" />
+    <link type="text/css" href="./skin/taskbar.css?cacheid=80d56607" rel="Stylesheet" />
     <link type="text/css" href="./skin/autoComplete/css/autoComplete.css?cacheid=ef30cd42" rel="Stylesheet" />
     <script type="text/javascript" src="./skin/polyfills.js?cacheid=a0e0343d"></script>
     <script type="module" src="./skin/i18n.js?cacheid=071abc9a" defer></script>
-    <script type="text/javascript" src="./skin/languages.js?cacheid=5be77f5c" defer></script>
-    <script type="text/javascript" src="./skin/viewer.js?cacheid=5fc4badf" defer></script>
+    <script type="text/javascript" src="./skin/languages.js?cacheid=ee7d95b5" defer></script>
+    <script type="text/javascript" src="./skin/viewer.js?cacheid=aca897b0" defer></script>
     <script type="text/javascript" src="./skin/autoComplete/autoComplete.min.js?cacheid=1191aaaf"></script>
       const blankPageUrl = root + "/skin/blank.html?cacheid=6b1fa032";
           <label for="kiwix_button_show_toggle"><img src="./skin/caret.png?cacheid=22b942b4" alt=""></label>
@@ -356,6 +359,57 @@ R"EXPECTEDRESULT(    <link type="text/css" href="/ROOT%23%3F/skin/search_results
   }
 }
 
+std::string getCacheIdFromUrl(const std::string& url)
+{
+  const std::string q("?cacheid=");
+  const auto i = url.find(q);
+  return i == std::string::npos ? "" : url.substr(i + q.size());
+}
+
+std::string runExternalCmdAndGetItsOutput(const std::string& cmd)
+{
+  std::string cmdOutput;
+
+#ifdef _WIN32
+#define popen _popen
+#define pclose _pclose
+#endif
+
+  if (FILE* pPipe = popen(cmd.c_str(), "r"))
+  {
+    char buf[128];
+    while (fgets(buf, 128, pPipe)) {
+        cmdOutput += std::string(buf, buf+128);
+    }
+
+    pclose(pPipe);
+  }
+
+  return cmdOutput;
+}
+
+std::string getSha1OfResponseData(const std::string& url)
+{
+  const std::string pythonScript =
+    "import urllib.request as req; "
+    "import hashlib; "
+    "print(hashlib.sha1(req.urlopen('" + url + "').read()).hexdigest())";
+  const std::string cmd = "python3 -c \"" + pythonScript + "\"";
+  return runExternalCmdAndGetItsOutput(cmd);
+}
+
+TEST_F(ServerTest, CacheIdsOfStaticResourcesMatchTheSha1HashOfResourceContent)
+{
+  for ( const Resource& res : all200Resources() ) {
+    if ( res.kind == STATIC_CONTENT ) {
+      const TestContext ctx{ {"url", res.url} };
+      const std::string fullUrl = "http://localhost:" + std::to_string(SERVER_PORT) + res.url;
+      const std::string sha1 = getSha1OfResponseData(fullUrl);
+      ASSERT_EQ(sha1.substr(0, 8), getCacheIdFromUrl(res.url)) << ctx;
+    }
+  }
+}
+
 const char* urls400[] = {
   "/ROOT%23%3F/search",
   "/ROOT%23%3F/search?content=zimfile",
@@ -1152,13 +1206,18 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "iso_code": "dag",
     "self_name": "Silimiinsili",
-    "translation_count": 24
+    "translation_count": 48
   },
   {
     "iso_code": "de",
     "self_name": "Deutsch",
     "translation_count": 57
   },
+  {
+    "iso_code": "el",
+    "self_name": "Αγγλικά",
+    "translation_count": 23
+  },
   {
     "iso_code": "en",
     "self_name": "English",
@@ -1167,12 +1226,12 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "iso_code": "es",
     "self_name": "español",
-    "translation_count": 48
+    "translation_count": 49
   },
   {
     "iso_code": "fi",
     "self_name": "suomi",
-    "translation_count": 22
+    "translation_count": 29
   },
   {
     "iso_code": "fr",
@@ -1202,7 +1261,7 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "iso_code": "ia",
     "self_name": "interlingua",
-    "translation_count": 49
+    "translation_count": 57
   },
   {
     "iso_code": "ig",
@@ -1212,7 +1271,7 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "iso_code": "it",
     "self_name": "italiano",
-    "translation_count": 34
+    "translation_count": 38
   },
   {
     "iso_code": "ja",
@@ -1222,7 +1281,7 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "iso_code": "ko",
     "self_name": "한국어",
-    "translation_count": 13
+    "translation_count": 15
   },
   {
     "iso_code": "ku-latn",
@@ -1264,6 +1323,11 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
     "self_name": "Polski",
     "translation_count": 31
   },
+  {
+    "iso_code": "pt-br",
+    "self_name": "Português",
+    "translation_count": 35
+  },
   {
     "iso_code": "ru",
     "self_name": "русский",
@@ -1299,6 +1363,11 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
     "self_name": "Svenska",
     "translation_count": 57
   },
+  {
+    "iso_code": "sw",
+    "self_name": "Kiswahili",
+    "translation_count": 57
+  },
   {
     "iso_code": "te",
     "self_name": "ఇంగ్లీషు",
@@ -1311,8 +1380,8 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   },
   {
     "iso_code": "zh-hans",
-    "self_name": "英语",
-    "translation_count": 54
+    "self_name": "简体中文",
+    "translation_count": 57
   },
   {
     "iso_code": "zh-hant",
